==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/AuthProviderConfigBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AuthProviderConfigBuilder extends AuthProviderConfigFluentImpl<AuthProviderConfigBuilder> implements VisitableBuilder<AuthProviderConfig,AuthProviderConfigBuilder>{
  public AuthProviderConfigBuilder() {
    this(false);
  }
  public AuthProviderConfigBuilder(Boolean validationEnabled) {
    this(new AuthProviderConfig(), validationEnabled);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AuthProviderConfig(), validationEnabled);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent,AuthProviderConfig instance) {
    this(fluent, instance, false);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent,AuthProviderConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withConfig(instance.getConfig());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AuthProviderConfigBuilder(AuthProviderConfig instance) {
    this(instance,false);
  }
  public AuthProviderConfigBuilder(AuthProviderConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AuthProviderConfigFluent<?> fluent;
  Boolean validationEnabled;
  public AuthProviderConfig build() {
    AuthProviderConfig buildable = new AuthProviderConfig(fluent.getConfig(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/AuthProviderConfigBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AuthProviderConfigBuilder extends AuthProviderConfigFluent<AuthProviderConfigBuilder> implements VisitableBuilder<AuthProviderConfig,AuthProviderConfigBuilder>{
  public AuthProviderConfigBuilder() {
    this(false);
  }
  public AuthProviderConfigBuilder(Boolean validationEnabled) {
    this(new AuthProviderConfig(), validationEnabled);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AuthProviderConfig(), validationEnabled);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent,AuthProviderConfig instance) {
    this(fluent, instance, false);
  }
  public AuthProviderConfigBuilder(AuthProviderConfigFluent<?> fluent,AuthProviderConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AuthProviderConfig());

    if (instance != null) {
      fluent.withConfig(instance.getConfig());
      fluent.withName(instance.getName());
      fluent.withConfig(instance.getConfig());
      fluent.withName(instance.getName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AuthProviderConfigBuilder(AuthProviderConfig instance) {
    this(instance,false);
  }
  public AuthProviderConfigBuilder(AuthProviderConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AuthProviderConfig());

    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withName(instance.getName());
      this.withConfig(instance.getConfig());
      this.withName(instance.getName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AuthProviderConfigFluent<?> fluent;
  Boolean validationEnabled;
  public AuthProviderConfig build() {
    AuthProviderConfig buildable = new AuthProviderConfig(fluent.getConfig(),fluent.getName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
